# [2.5.0](https://github.com/seriaati/enka-py/compare/v2.4.8..v2.5.0) - 2025-04-19

## Bug Fixes

- Change Enka API-docs source to PizzaStudio - ([29d6823](https://github.com/seriaati/enka-py/commit/29d682312639baa93b87884f4c2ee6a9150c7a05))
- Fix text map not updated after asset update - ([1c26562](https://github.com/seriaati/enka-py/commit/1c26562bee7c969ff12620d47256d9720bd2f3b1))
- Update StrEnum import logic for Python version compatibility - ([92ef254](https://github.com/seriaati/enka-py/commit/92ef2549b9ee54577d894c0a7a7f7d0c8184bae5))
- Update language conversion logic - ([c12bae8](https://github.com/seriaati/enka-py/commit/c12bae8ed115ec2fab7be07e03a5e79650e821f4))
- Add class methods to field validators - ([9983604](https://github.com/seriaati/enka-py/commit/998360466d842f95c334012e49b89a098fa50e25))

## Documentation

- Add documentation ([#101](https://github.com/seriaati/enka-py/issues/101)) - ([8e37e9a](https://github.com/seriaati/enka-py/commit/8e37e9a38fda9ba3da513f43fe1dc1bdcad9e3b8))

## Features

- Allow setting value via BaseAssetData.data - ([363c628](https://github.com/seriaati/enka-py/commit/363c62887001efc2ef4eb04a243ab27e068feece))
- Add ZZZ support ([#96](https://github.com/seriaati/enka-py/issues/96)) - ([2204f3a](https://github.com/seriaati/enka-py/commit/2204f3a86532fb42312778976c05184ae6587c66))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#98](https://github.com/seriaati/enka-py/issues/98)) - ([4aad548](https://github.com/seriaati/enka-py/commit/4aad548f774e76e64bb64a0852cb7565476a074d))
- **(deps)** lock file maintenance ([#99](https://github.com/seriaati/enka-py/issues/99)) - ([91048b7](https://github.com/seriaati/enka-py/commit/91048b742f8011af0a42cd3e0282a912fd6df243))
- **(deps)** lock file maintenance ([#100](https://github.com/seriaati/enka-py/issues/100)) - ([dd347b9](https://github.com/seriaati/enka-py/commit/dd347b930ed7e15c07c1198a4e049e549f91e8f2))
- Update ruff config - ([0b63c7f](https://github.com/seriaati/enka-py/commit/0b63c7fe759d4aebe95a1ff5986dc761b69c21ec))

## Refactoring

- Remove useless async in non-async func - ([fa6808a](https://github.com/seriaati/enka-py/commit/fa6808ae34d70c446dbc0175342d9c5cd5149ece))

